AuthSubmitBloc class
- Inheritance
-
- Object
- BaseSubmitBloc<
AuthBlocEvent> - AuthSubmitBloc
Constructors
- AuthSubmitBloc(String email, AuthBlocEvent initialPayload, {required AuthBloc authBloc})
Properties
- allowResubmission → bool
-
Whether to allow payload updates and new submissions after a successful submission.
Defaults to false to prevent accidental double-submissions or state divergence.
no setterinherited
- authBloc → AuthBloc
-
final
- email → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialPayload ↔ AuthBlocEvent
-
getter/setter pairinherited
- isClosed → bool
-
Whether the bloc is closed.
no setterinherited
- isFormValid ↔ bool
-
getter/setter pairinherited
- payloadChanged ↔ bool
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ BaseSubmitState<
AuthBlocEvent> -
The current state.
no setterinherited
- storage → BaseHyttaHubStorage
-
no setterinherited
- storageType → StorageEnum
-
Implement in subclasses
no setteroverride
-
stream
→ Stream<
BaseSubmitState< AuthBlocEvent> > -
The current stream of states.
no setterinherited
Methods
-
add(
BaseSubmitEvent< AuthBlocEvent> event) → void -
Notifies the
Blocof a neweventwhich triggers all correspondingEventHandlerinstances.inherited -
addError(
Object error, [StackTrace? stackTrace]) → void -
Reports an
errorwhich triggersonErrorwith an optional StackTrace.inherited -
close(
) → Future< void> -
Closes the
eventandstateStreams. This method should be called when aBlocis no longer needed. Oncecloseis called,eventsthat areadded will not be processed. In addition, ifcloseis called whileeventsare still being processed, theBlocwill finish processing the pendingevents.inherited -
emit(
BaseSubmitState< AuthBlocEvent> state) → void -
emitis only for internal use and should never be called directly outside of tests. TheEmitterinstance provided to eachEventHandlershould be used instead.inherited -
getAuthor(
BaseSubmitState< AuthBlocEvent> state) → Future<BaseSubmitState< AuthBlocEvent> > -
Implement in subclasses
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on<
E extends Event> (EventHandler< E, BaseSubmitState< handler, {EventTransformer<AuthBlocEvent> >E> ? transformer}) → void -
Register event handler for an event of type
E. There should only ever be one event handler per event typeE.inherited -
onChange(
Change< BaseSubmitState< change) → voidAuthBlocEvent> > -
Called whenever a
changeoccurs with the givenchange. Achangeoccurs when a newstateis emitted.onChangeis called before thestateof thecubitis updated.onChangeis a great spot to add logging/analytics for a specificcubit.inherited -
onDone(
BaseSubmitEvent< AuthBlocEvent> event, [Object? error, StackTrace? stackTrace]) → void -
Called whenever an
eventhandler for a specificBlochas completed. This may include anerrorandstackTraceif an uncaught exception occurred within the event handler.inherited -
onError(
Object error, StackTrace stackTrace) → void -
Called whenever an
erroroccurs and notifiesBlocObserver.onError.inherited -
onEvent(
BaseSubmitEvent< AuthBlocEvent> event) → void -
Called whenever an
eventisadded to theBloc. A great spot to add logging/analytics at the individualBloclevel.inherited -
onTransition(
Transition< BaseSubmitEvent< transition) → voidAuthBlocEvent> , BaseSubmitState<AuthBlocEvent> > -
Called whenever a
transitionoccurs with the giventransition. Atransitionoccurs when a neweventis added and a new state isemittedfrom a correspondingEventHandler.inherited -
submit(
BaseSubmitState< AuthBlocEvent> state, Emitter<BaseSubmitState< emitter) → Future<AuthBlocEvent> >BaseSubmitState< AuthBlocEvent> > -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
submitAuthEvent(
BaseSubmitState< AuthBlocEvent> state, String email, BaseHyttaHubStorage storage, AuthBloc authBloc) → Future<BaseSubmitState< AuthBlocEvent> >