BaseSubmitEvent<T extends GeneratedMessage> class abstract

Implementers

Constructors

BaseSubmitEvent({T? updatedPayload, required CommonSubmitBlocEvent submission})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
submission CommonSubmitBlocEvent
final
updatedPayload ↔ T?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited