BaseCheckboxFormField<B extends BaseSubmitBloc<T>, E extends BaseSubmitEvent<T>, T extends GeneratedMessage> class abstract

Inheritance
Implementers

Constructors

BaseCheckboxFormField({Key? key, required String labelText, required GlobalKey<FormState> formKey, required E eventFactory({required CommonSubmitBlocEvent submission, T? updatedPayload}), bool showErrorMessage = false})
const

Properties

eventFactory → E Function({required CommonSubmitBlocEvent submission, T? updatedPayload})
final
formKey GlobalKey<FormState>
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelText String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showErrorMessage bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<BaseCheckboxFormField<B, E, T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getValueFromPayload(T payload) bool
Implement in subclasses to extract the field's value from the payload.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updatePayload(T originalPayload, bool newValue) → T
Implement in subclasses to update the payload with the new value.
validator(BuildContext context, bool value) String?
Implement in subclasses to provide validation logic.

Operators

operator ==(Object other) bool
The equality operator.
inherited