getItemsFromPayload abstract method
Implement in subclasses to extract the list of items from the payload.
Implementation
List<ReorderableItem> getItemsFromPayload(BuildContext context, T payload);
Implement in subclasses to extract the list of items from the payload.
List<ReorderableItem> getItemsFromPayload(BuildContext context, T payload);