updatePayload abstract method
Implement in subclasses to update the payload with the new list of items.
Implementation
T updatePayload(T originalPayload, List<ReorderableItem> newItems);
Implement in subclasses to update the payload with the new list of items.
T updatePayload(T originalPayload, List<ReorderableItem> newItems);