updatePayload abstract method
Implement in subclasses to update the payload with the new value.
Implementation
T updatePayload(T originalPayload, String newValue);
Implement in subclasses to update the payload with the new value.
T updatePayload(T originalPayload, String newValue);