EventsDisplayConfig<R extends GeneratedMessage, S extends GeneratedMessage> class abstract

Abstract configuration to drive the generic EventsDisplay widget.

Implement this class for each event type (Service, Account, Site) to provide the specific paths, titles, and parsing/replaying logic.

Implementers

Constructors

EventsDisplayConfig()

Properties

collectionPath String
no setter
hashCode int
The hash code for this object.
no setterinherited
replayTitle String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenTitle String
no setter

Methods

getIsoDate(R record) String
getVersion(R record) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseRecord(Map<String, dynamic> data, String isoDate, String payload) → R
replay(Map<int, String> base64Events) → S
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited