proto/allowed_emails_bloc.pb library

Classes

AllowedEmailsBlocEvent
Fetch the allowed emails for the service or a site The emails are stored outside of the events
AllowedEmailsBlocEvent_FetchedAllowedEmails
AllowedEmailsBlocState
AllowedEmailsBlocState_State
AllowedEmailsBlocState_UserInfo

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.