proto/service_events.pb library

Classes

ServiceEvent
these records are permanently stored in firebase and read by the client, so do not include email or any other PII
ServiceEvent_AddServiceAdmin
ServiceEvent_InitialEvent
ServiceEvent_MinimumVersionRequired
ServiceEvent_PrivacyPolicy
ServiceEvent_RemoveServiceAdmin
ServiceEvent_RestoreServiceAdmin
ServiceEvent_ServiceStatus
ServiceEvent_TermsOfService
ServiceEvent_UpdateServiceAdmin
ServiceEventRecord
The ServiceEventRecord is a representation of the actual record stored in the database This record is used just for display purposes in the client
SubmitServiceEvent
The SubmitServiceEvent is passed to the submit bloc handler, so it can contain PII

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.