ServiceEventsConfig class

Inheritance

Constructors

ServiceEventsConfig(HyttaHubLocalizations localizations)

Properties

collectionPath String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
localizations HyttaHubLocalizations
final
replayTitle String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenTitle String
no setteroverride

Methods

getIsoDate(ServiceEventRecord record) String
override
getVersion(ServiceEventRecord record) int
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseRecord(Map<String, dynamic> data, String isoDate, String payload) ServiceEventRecord
override
replay(Map<int, String> base64Events) ServiceReplayBlocState
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited