UpdateMemberEmailInputWidget class

Inheritance

Constructors

UpdateMemberEmailInputWidget({Key? key, required GlobalKey<FormState> formKey, required Map<String, AllowedEmailsBlocState_UserInfo> allowedEmails, required String originalEmail, required String labelText})
const

Properties

allowedEmails Map<String, AllowedEmailsBlocState_UserInfo>
final
eventFactory SiteEventSubmission Function({required CommonSubmitBlocEvent submission, SubmitSiteEvent? updatedPayload})
finalinherited
formKey GlobalKey<FormState>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelText String
finalinherited
maxLength int?
finalinherited
maxLines int?
finalinherited
obscureText bool?
finalinherited
originalEmail String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffixIcon Widget?
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<BaseTextFormField<SiteSubmitBloc, SiteEventSubmission, SubmitSiteEvent>>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getValueFromPayload(SubmitSiteEvent payload) String
Implement in subclasses to extract the field's value from the payload.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updatePayload(SubmitSiteEvent originalPayload, String newValue) SubmitSiteEvent
Implement in subclasses to update the payload with the new value.
override
validator(BuildContext context, String value) String?
Implement in subclasses to provide validation logic.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited