BloomFilterProcessor class

Constructors

BloomFilterProcessor({required int size, required int hashCount, Uint8List? bitArray})

Properties

bitArray Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
hashCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final

Methods

add(String item) → void
addAll(List<String> items) → void
mightContain(String item) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited