HyttaHubImplementationDescriptor class

A descriptor for a HyttaHub implementation.

Constructors

HyttaHubImplementationDescriptor({required String id, required String name, required StorageEnum type, BaseHyttaHubStorage storageBuilder()?, BaseHyttaHubAuth authBuilder()?, BaseHyttaHubFunctions functionsBuilder()?, BaseHyttaHubInternalStorage internalStorageBuilder()?})

Properties

authBuilder BaseHyttaHubAuth Function()?
final
functionsBuilder BaseHyttaHubFunctions Function()?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
internalStorageBuilder BaseHyttaHubInternalStorage Function()?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageBuilder BaseHyttaHubStorage Function()?
final
type StorageEnum
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited