ReorderableItem class
A helper class to represent an item in a reorderable list.
Constructors
- ReorderableItem({required int id, required String title, Widget? titleWidget, required Widget leading})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override