WrappedRegExp class
A wrapper class that implements Pattern to encapsulate RegExp.
Under certain IDE and SDK configurations, RegExp triggers a deprecation
warning because the class signature will become final in a future
Dart release. Wrapping it in a lightweight Pattern implementer averts
the barrage of lint warnings without resorting to // ignore.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allMatches(
String string, [int start = 0]) → Iterable< Match> -
Matches this pattern against the string repeatedly.
override
-
hasMatch(
String input) → bool -
matchAsPrefix(
String string, [int start = 0]) → Match? -
Matches this pattern against the start of
string.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited